@@ -49,7 +49,9 @@ def path_reference_code(save_name):
     reference_code = str(zlib.crc32(bytes(save_name, 'UTF-8')))[:6]
     return reference_code
 
-def generate_filepath(para_combination,folder='',file_format='parquet'):
+def generate_filepath(para_combination, folder=''):
+
+    file_format = para_combination['file_format']
 
     if not file_format == 'parquet':
         file_format = 'csv'
@@ -78,8 +80,6 @@ def mp_cal_performance(tuple_data):
 
 
 def generate_backtest_result(all_para_combination, number_of_core=8, risk_free_rate='geometric_mean'):
-
-
     ## Get / Calculate risk free rate
     start_date = all_para_combination[0]['start_date']
     end_date = all_para_combination[0]['end_date']
@@ -98,6 +98,7 @@ def generate_backtest_result(all_para_combination, number_of_core=8, risk_free_r
     else:
         print('Risk free rate: {:.2f} %'.format(risk_free_rate))
 
+    print('Backtest result is loading. Please wait patiently.')
 
 
     manager_list = mp.Manager().list()# To save the result with index number
@@ -293,7 +294,7 @@ def resample_summary_to_daily(para_combination, folder=''):
     multiplier = sec_profile['multiplier']
 
     # Read backtest data
-    save_path = generate_filepath(para_combination=para_combination,folder=folder,file_format=file_format)
+    save_path = generate_filepath(para_combination=para_combination,folder=folder)
     if file_format == 'parquet':
         df_backtest = pd.read_parquet(save_path) # Daraframe that may not be daily
         ### parquet specific, All backtest force to treart as summary, # ie filter action only
@@ -474,7 +475,6 @@ def resample_summary_to_daily(para_combination, folder=''):
 
 
 def cal_performance(para_combination):
-
     start_date = para_combination['start_date']
     end_date = para_combination['end_date']
 
@@ -488,7 +488,7 @@ def cal_performance(para_combination):
     if (intraday or summary_mode):
         df_daily = resample_summary_to_daily(para_combination=para_combination)
     else:
-        save_path = generate_filepath(para_combination=para_combination, file_format=file_format)
+        save_path = generate_filepath(para_combination=para_combination)
         if file_format == 'parquet':
             df_backtest = pd.read_parquet(save_path)  # Daraframe that may not be daily
         else:
@@ -551,7 +551,7 @@ def cal_performance(para_combination):
 
         # Win Rate (need to use df_backtest directly)
 
-        save_path = generate_filepath(para_combination=para_combination, file_format=file_format)
+        save_path = generate_filepath(para_combination=para_combination)
         if file_format == 'parquet':
             df_backtest = pd.read_parquet(save_path)  # Daraframe that may not be daily
         else:
@@ -648,6 +648,5 @@ def cal_performance(para_combination):
     result_dict['return_to_bah'] = return_on_capital - bah_return
 
 
-
     return result_dict
 
