@@ -488,7 +488,7 @@ class Components:
         # isolate missing timestamps
         dt_breaks = [d for d in dt_all.strftime("%Y-%m-%d %H:%M:%S").tolist() if not d in dt_obs]
 
-        save_path = plotguy.generate_filepath(para_combination=para_combination, file_format=file_format)
+        save_path = plotguy.generate_filepath(para_combination=para_combination)
         if file_format == 'parquet':
             df_signal_list = pd.read_parquet(save_path)  # Daraframe that may not be daily
         else:
@@ -607,7 +607,7 @@ class Components:
             if (intraday or summary_mode):
                 df_daily = plotguy.resample_summary_to_daily(para_combination=para_combination)
             else:
-                save_path = plotguy.generate_filepath(para_combination=para_combination, file_format=file_format)
+                save_path = plotguy.generate_filepath(para_combination=para_combination)
                 if file_format == 'parquet':
                     df_backtest = pd.read_parquet(save_path)  # Daraframe that may not be daily
                 else:
@@ -737,7 +737,7 @@ class Components:
     def generate_chart_2_full(self, para_combination, line_colour, settings):
         file_format = para_combination['file_format']
 
-        save_path = plotguy.generate_filepath(para_combination=para_combination, file_format=file_format)
+        save_path = plotguy.generate_filepath(para_combination=para_combination)
         if file_format == 'parquet':
             df_backtest = pd.read_parquet(save_path)  # Daraframe that may not be daily
         else:
